# qp

Quantile parametrization for probability distribution functions.

[![Build Status](https://img.shields.io/github/workflow/status/LSSTDESC/qp/Python%20package?logo=Github)](https://github.com/LSSTDESC/qp/actions/workflows/python-package.yml)[![Documentation Status](https://img.shields.io/readthedocs/qp/main?logo=readthedocs&logoColor=white)](http://qp.readthedocs.io/en/latest/)


## Motivation
This repository exists for two reasons.

1. To be the home of `qp`, a python package for handling probability distributions using various parametrizations, including a set of quantiles;
2. To help us learn best practices in software carpentry.

## Examples

* **[Basic Demo](http://htmlpreview.github.io/?https://github.com/LSSTDESC/qp/blob/master/docs/demo.html)** [(raw notebook)](https://github.com/LSSTDESC/qp/blob/master/nb/demo.ipynb)

* **[Practical Example](http://htmlpreview.github.io/?https://github.com/LSSTDESC/qp/blob/master/docs/practical_example.html)** [(raw notebook)](https://github.com/LSSTDESC/qp/blob/master/nb/practical_example.ipynb)

Also: [Read the Docs](http://qp.readthedocs.io/)


## People

* [Alex Malz](https://github.com/LSSTDESC/qp/issues/new?body=@aimalz) (NYU)
* [Phil Marshall](https://github.com/LSSTDESC/qp/issues/new?body=@drphilmarshall) (SLAC)
* [Eric Charles](https://github.com/LSSTDESC/qp/issues/new?body=@eacharles) (SLAC)
* [Sam Schmidt](https://github.com/LSSTDESC/qp/issues/new?body=@sschmidt) (UC Davis)

## License, Contributing etc

The code in this repo is available for re-use under the MIT license, which means that you can do whatever you like with it, just don't blame us. If you end up using any of the code or ideas you find here in your academic research, please cite us as `Malz et al, ApJ 156 1 35`. If you are interested in this project, please do drop us a line via the hyperlinked contact names above, or by [writing us an issue](https://github.com/aimalz/qp/issues/new). To get started contributing to the `qp` project, just fork the repo - pull requests are always welcome!





